@@ -133,6 +133,14 @@ def extractPlaceOfPublication(title):
         place = place.strip()
     return place
 
+def remarks2BhlID(s):
+    bhlid = None
+    if s is not None and s is not np.nan:
+        m = re.search('BHL_title_ID\:([0-9]+)', s, re.IGNORECASE)
+        if m is not None:
+            bhlid=m.group(1)
+    return bhlid
+    
 def main():
     pass
 
